@@ -18,6 +18,8 @@
   along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <utility>
+
 #include "networkadjustmentpanel.h"
 #include "selectconfiguration.h"
 #include "constants.h"
@@ -178,7 +180,7 @@ NetworkAdjustmentPanel::NetworkAdjustmentPanel(QString connectionName, QWidget *
         if (!map.empty())
         {
             menuTools->setEnabled(true);
-            for (auto i : qAsConst(map))
+            for (auto i : std::as_const(map))
             {
                 PluginAction<AdjustmentInterface>* action = new PluginAction<AdjustmentInterface>(this, i);
                 menuTools->addAction(action);
@@ -209,7 +211,7 @@ NetworkAdjustmentPanel::NetworkAdjustmentPanel(QString connectionName, QWidget *
 
 NetworkAdjustmentPanel::~NetworkAdjustmentPanel()
 {
-    for (auto w : qAsConst(localPluginsList)) delete w;
+    for (auto w : std::as_const(localPluginsList)) delete w;
     allNetworkAdjustmentPanelsList.removeOne(this);
 }
 
@@ -233,7 +235,7 @@ void NetworkAdjustmentPanel::draw_network_configuration()
 
 void NetworkAdjustmentPanel::update_point_editor_table()
 {
-    ped->connectPointData      (&adj.get_local_network()->PD);
+    ped->connectPointData(adj.get_local_network());
 }
 
 void NetworkAdjustmentPanel::update_observation_editor_table()
@@ -364,7 +366,7 @@ void NetworkAdjustmentPanel::getConfigurationName(QString conf, bool tabbed)
         tabifyDockWidget(dockpar, dockoed);
         menuView->addAction(dockoed->toggleViewAction());
 
-        QDockWidget* docksvg = new QDockWidget(tr("view"), this);
+        QDockWidget* docksvg = new QDockWidget(tr("View"), this);
         docksvg->setWidget(svg);
         tabifyDockWidget(dockpar, docksvg);
         menuView->addAction(docksvg->toggleViewAction());
@@ -380,12 +382,13 @@ void NetworkAdjustmentPanel::getConfigurationName(QString conf, bool tabbed)
     connect(par,  SIGNAL(angular_units_changed()), this, SLOT(update_observation_editor_table()));
     connect(par,  SIGNAL(angular_units_changed()), res,  SLOT(update_adjustment_results()));
 
+    connect(par,  SIGNAL(warning(QString)), this,  SLOT(status_bar(QString)));
     connect(ped,  SIGNAL(warning(QString)), this,  SLOT(status_bar(QString)));
     connect(obs,  SIGNAL(warning(QString)), this,  SLOT(status_bar(QString)));
 
     connect(&adj, SIGNAL(acord_signal()),          this, SLOT(update_point_editor_table()));
     connect(&adj, SIGNAL(adjustment_signal(bool)), this, SLOT(draw_network_configuration()));
-    connect(&adj, SIGNAL(adjustment_signal(bool)), this, SLOT(update_adjustment_results (bool)));
+    connect(&adj, SIGNAL(adjustment_signal(bool)), this, SLOT(update_adjustment_results(bool)));
     connect(&adj, SIGNAL(adjustment_signal(bool)), this, SLOT(update_point_editor_table()));
     connect(&adj, SIGNAL(adjustment_signal(bool)), this, SLOT(update_observation_editor_table()));
 
@@ -710,11 +713,11 @@ void NetworkAdjustmentPanel::action_Parameters_changed()
     QString text;
     if (edit)
     {
-        text = tr("Editing of Parameters is enabled");
+        text = tr("Editing Parameters is enabled");
     }
     else
     {
-        text = tr("Editing of Parameters is disabled");
+        text = tr("Editing Parameters is disabled");
     }
     par->enableEdit(edit);
 
@@ -727,11 +730,11 @@ void NetworkAdjustmentPanel::action_Points_changed()
     QString text;
     if (edit)
     {
-        text = tr("Editing of Points is enabled");
+        text = tr("Editing Points is enabled");
     }
     else
     {
-        text = tr("Editing of Points is disabled");
+        text = tr("Editing Points is disabled");
     }
     ped->enableEdit(edit);
 
@@ -744,11 +747,11 @@ void NetworkAdjustmentPanel::action_Observations_changed()
     QString text;
     if (edit)
     {
-        text = tr("Editing of Observations is enabled");
+        text = tr("Editing Observations is enabled");
     }
     else
     {
-        text = tr("Editing of Observations is disabled");
+        text = tr("Editing Observations is disabled");
     }
     obs->enableEdit(edit);
 
