@@ -22,10 +22,7 @@
 #define POINTEDITOR_H
 
 #include <QWidget>
-
-namespace GNU_gama { namespace local {
-    class PointData;
-}}
+#include <gnu_gama/local/network.h>
 
 class PointTableModel;
 class QMenu;
@@ -39,12 +36,13 @@ public:
     explicit PointEditor(QWidget *parent = nullptr);
     ~PointEditor();
 
-    void connectPointData(GNU_gama::local::PointData* pd);
+    void connectPointData(GNU_gama::local::LocalNetwork* plnet);
     void enableEdit(bool edit);
     
 private:
+    GNU_gama::local::LocalNetwork* lnet {nullptr};
     QTableView* tableView;
-    PointTableModel* model;
+    PointTableModel* pointModel;
     QMenu* pointMenu;
     bool   readonly;
     int    pointLogicalIndex;
@@ -55,6 +53,7 @@ signals:
 private slots:
     void pointContextMenu(QPoint p);
     void pointDelete();
+    void pointChanged();
 };
 
 #endif // POINTEDITOR_H
