@@ -452,9 +452,9 @@ void QGamaControlPanel::on_action_About_qgama_triggered()
                   " Copyright (C) " + QGama::copyright + " Aleš Čepek <i>et al.</i></p>"
                   "<p>" +
                   QString(tr("Based on <a href='http://www.gnu.org/software/gama'>"
-                             "GNU gama</a> version %1")
+                             "GNU gama</a> %1")
                          ).arg(GNU_gama::GNU_gama_version().c_str()) +
-                  "  and Qt " + QString(qVersion()) +
+                  "  and Qt " + QString(qVersion()) + " " + ABOUT_KIT_NAME
                   "</p>"
 
                   "<p>This program is free software: you can redistribute it and/or modify "
